@@ -1,13 +1,6 @@
-# -*- coding: UTF-8 -*-
-'''
-    nereid
+#This file is part of Tryton & Nereid. The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 
-    A fullstack web framework based on Flask, but powered by Tryton
-
-    :copyright: (c) 2010-2012 by Openlabs Technologies & Consulting (P) Ltd.
-    :copyright: (c) 2010 by Armin Ronacher
-    :license: GPLv3, see LICENSE for more details
-'''
 from __future__ import with_statement
 
 import os
