@@ -1,15 +1,5 @@
-# -*- coding: utf-8 -*-
-"""
-    nereid.globals
-    ~~~~~~~~~~~~~
-
-    Defines all the global objects that are proxies to the current
-    active context.
-
-    :copyright: (c) 2010-2012 by Openlabs Technologies & Consulting (P) Ltd.
-    :copyright: (c) 2010 by Armin Ronacher.
-    :license: GPLv3, see LICENSE for more details.
-"""
+#This file is part of Tryton & Nereid. The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 from flask.globals import (_request_ctx_stack, current_app,
     request, _lookup_object, session, g, LocalProxy)
 
