@@ -1,12 +1,5 @@
-# -*- coding: UTF-8 -*-
-'''
-    nereid.session
-
-    Implements cookie based sessions
-
-    :copyright: (c) 2010-2012 by Openlabs Technologies & Consulting (P) Ltd.
-    :license: GPLv3, see LICENSE for more details
-'''
+#This file is part of Tryton & Nereid. The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 from datetime import datetime
 
 from flask.sessions import SessionInterface, SessionMixin
