@@ -1,18 +1,9 @@
-# -*- coding: UTF-8 -*-
-'''
-    nereid.wrappers
-
-    Implements the WSGI wrappers
-
-    :copyright: (c) 2010-2012 by Openlabs Technologies & Consulting (P) Ltd.
-    :license: GPLv3, see LICENSE for more details
-'''
-from werkzeug import redirect, abort
+#This file is part of Tryton & Nereid. The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 from werkzeug.utils import cached_property
 from flask.wrappers import Request as RequestBase, Response as ResponseBase
 from flask.helpers import flash
 from .globals import current_app, session
-from .helpers import url_for
 
 
 def _get_website_name(host):
@@ -40,14 +31,7 @@ class Request(RequestBase):
         NereidUser = current_app.pool.get('nereid.user')
         if 'user' not in session:
             return NereidUser(self.nereid_website.guest_user.id)
-
-        try:
-            nereid_user, = NereidUser.search([('id', '=', session['user'])])
-        except ValueError:
-            session.pop('user')
-            abort(redirect(url_for('nereid.website.login')))
-        else:
-            return nereid_user
+        return NereidUser(session['user'])
 
     @cached_property
     def nereid_currency(self):
